# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

## [Unreleased](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.1.4...HEAD)

### Merged

*   Incorrect Importing of vseq script [`#382`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/382)
*   Kjkoeller patch 3 [`#381`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/381)
*   GUI Startup [`#380`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/380)
*   Documentation Updates [`#379`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/379)
*   Paper Reference for GAIA-TESS Calculations [`#378`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/378)
*   Potential Crashing [`#377`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/377)
*   Bump braces from 3.0.2 to 3.0.3 in /changelog [`#376`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/376)
*   Header Correct Command Line [`#374`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/374)
*   Turn into a Callable Function [`#375`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/375)
*   Header Correction [`#373`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/373)
*   Functions for Validating Files/Directories [`#372`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/372)
*   Allows for standard version printing [`#371`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/371)
*   Latex Output Error [`#369`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/369)
*   Pipeline Capabilities and Cleanup [`#367`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/367)
*   Significant Comments Added [`#368`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/368)

### Commits

*   Calling Package Crashing [`a47b588`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a47b58806932f606ea62a5a9e048222858ea6be2)
*   Misspelling [`834be2c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/834be2cc6a3d3638e97e5f905cf23a714faff875)
*   Rename header-correct.py to headerCorrect.py [`55a87c0`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/55a87c0db91f9995736bb68965e655988feb7254)

## [v4.1.4](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.1.3...v4.1.4) - 2024-04-27

### Merged

*   Returning More Deleted Functions [`#366`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/366)

### Commits

*   Update **init**.py [`a5cad3d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a5cad3d2ee568669d7b23b7ecc362bd8f312a650)
*   Update **init**.py [`8ea0e5c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8ea0e5c29fef9ce7a0cecdc492658faafca6d0e1)

## [v4.1.3](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.1.2...v4.1.3) - 2024-04-27

### Merged

*   Color Light Curve Updates [`#365`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/365)
*   Another Missing Deleted Function [`#364`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/364)

## [v4.1.2](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.1.1...v4.1.2) - 2024-04-22

### Merged

*   Removed Required Functions [`#363`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/363)

## [v4.1.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.1.0...v4.1.1) - 2024-04-22

### Merged

*   Incorrect Formatting [`#362`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/362)

## [v4.1.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.0.8...v4.1.0) - 2024-04-19

### Merged

*   Memory Allocation [`#332`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/332)
*   Filter Files were Incorrect [`#361`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/361)
*   Remove All Unused Functions [`#359`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/359)

### Commits

*   Update README.md [`7904701`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7904701b6216dacd852f0c0faf35077d6fb30cf6)

## [v4.0.8](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.0.7...v4.0.8) - 2024-04-05

### Merged

*   Forgotten Uncommented Out Line [`#360`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/360)
*   Remove Some Unused Functions [`#358`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/358)
*   v4.0.7 [`#357`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/357)

## [v4.0.7](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.0.6...v4.0.7) - 2024-04-03

### Merged

*   Initial Unit Tests for IRAF Reduction [`#356`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/356)
*   Fixed Allowing for Various Observatory Sites [`#355`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/355)
*   Few Changes [`#353`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/353)
*   Automated Python Unit Test Workflow [`#352`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/352)
*   New Tests for OC\_plot [`#351`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/351)
*   OS and Python Versions Update [`#350`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/350)
*   Only Call Needed Functions [`#349`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/349)
*   v4.0.6 [`#348`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/348)
*   Utilize the Requirements.txt File [`#347`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/347)

### Commits

*   Overhaul of ReadtheDocs [`51b78b9`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/51b78b9e4dbbac8eb5ebd969a73ceb4318ab422f)
*   Update conf.py [`ab96657`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ab966572765c0879892e45c910868f9b976e2e1a)
*   Delete .github/workflows/tests.yml [`5331e3f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5331e3f35a86ee363417b4ed98f33a573d925974)
*   Update LICENSE [`0956491`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/0956491c01c9377adbdf15c4da8618f008816792)
*   Updated Package Requirments [`f075049`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f0750493ff6cd21ce1076354bcca10d8b8bf59ba)
*   Update requirements.txt [`656969f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/656969f862604db14e160732c23724fb7813fc64)
*   Update setup.cfg [`b701114`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b701114e1d340b9e63c391ce6f131379cce549d7)
*   Astropy v6.0.0 [`a561b5a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a561b5a276969ef1688add5cb985af8196182131)
*   Astropy v6.0.0 [`981be92`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/981be9220a44a421cfc5bbfcc13112b5eedc369c)
*   Typo [`d4b0f5d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d4b0f5d94ba95b0ec02b5b84d1aa33602ff1af84)
*   Pyia Version Update [`019e463`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/019e46370fd4e5fd7bbf522df9e7b09f0708a758)
*   Update conf.py [`3041f64`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/3041f64672bc06f31f560039d4af79c1179a2ff0)
*   Update .readthedocs.yml [`1d4c073`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/1d4c0739e71b139bbc6444ac3154f8f3ca8f0546)
*   Update .readthedocs.yml [`89033bd`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/89033bd700e4ed04cb87f986cf70437a4aae9e84)
*   HTML Theme [`d786a87`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d786a87df3b80b12dfdbffae72c5764cc43c048a)
*   Change Starting Year [`c826051`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/c8260514e144223569193c6141ce328422277892)
*   Update README.md [`8aa49b5`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8aa49b5f0643e1bf627da6582233790aa8aae1bf)
*   Update conf.py [`92b8b12`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/92b8b121dc5eaa9d9bd6772bdf1e51919a04c728)
*   Add Sphinx to Dependencies [`96d6be2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/96d6be21d95dc5b8473e4ea919b51577a10dc799)
*   Update conf.py [`c7974f7`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/c7974f7b9339faa4eea41cf656c2549b465bd11c)

## [v4.0.6](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.0.5...v4.0.6) - 2024-02-13

### Merged

*   Fixes Rounding Error from Floor Function [`#344`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/344)
*   Environment Versions Incorrect [`#346`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/346)
*   Pyia Requirement to 1.41 [`#345`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/345)
*   Commenting Out Broken Lines [`#343`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/343)
*   Python Version to Build.tools [`#342`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/342)
*   Switching from Image to OS [`#341`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/341)
*   Updating Tests [`#339`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/339)
*   Version 2 is Depreciated [`#338`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/338)

### Commits

*   Changing Pyia Requirement [`33f2bec`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/33f2bec7ccc7ff1e81c7e183e3e52f7db4e79df1)

## [v4.0.5](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.0.3...v4.0.5) - 2024-01-27

### Merged

*   Incorrect Gain Column [`#337`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/337)
*   Adds Paper For TESS CCD Information [`#336`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/336)
*   Incorrect Return Type [`#335`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/335)

### Commits

*   Update python-publish.yml [`6f6814b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/6f6814bd4678a81a5e4c18c5c561a03f92a10aa0)
*   Delete .github/workflows/python-publish.yml [`5561ec2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5561ec2ba79ecb58ed1eb062abc26948d21da7d6)
*   Create python-publish.yml [`d939d2a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d939d2a67daa733059eecc9f84df0d3cabb58fc1)
*   Update python-publish.yml [`cee6760`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/cee67608194645cb70adf6fadb8c776468768ebb)
*   Update python-publish.yml [`f690a9e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f690a9e933a35130d04ed8fe1c36dae906687d84)
*   Update python-publish.yml [`434e8bc`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/434e8bc82231e26e02614a6fb7d299f17fe5ba5b)
*   Update python-publish.yml [`50680cd`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/50680cdd99e8f8e61d1aa19bd5e00c6d3a451e50)
*   Update python-publish.yml [`5dbe692`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5dbe692ed6682b14a21ebecba9126049e0b05026)
*   Update python-publish.yml [`59bcedc`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/59bcedc02a8e42bac642382731c902d37aa072b6)
*   Publish Package Update [`ca5fa2c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ca5fa2cc9d457cadfa934cd5cdde8005369168c5)
*   Add Update Setuptools [`5041a69`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5041a695ae36b7fdfa8aa8d7faf4617826a8a93a)

## [v4.0.3](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.0.2...v4.0.3) - 2023-09-29

### Merged

*   Changing in Formatting Output [`#334`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/334)
*   Add Photutils Requirement [`#333`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/333)
*   Create tox.ini [`#329`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/329)
*   Angle Fixes [`#328`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/328)
*   Update ci\_tests.yml [`#326`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/326)
*   Missing Required Package [`#322`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/322)

## [v4.0.2](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.0.1...v4.0.2) - 2023-08-16

### Merged

*   Incorrect Import [`#321`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/321)

### Commits

*   Update **init**.py [`2588bba`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2588bba734cd0d426571d35c598fe2223c0c2663)

## [v4.0.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v4.0.0...v4.0.1) - 2023-08-16

### Merged

*   Comment Out Function Call [`#320`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/320)
*   v4.0.0 [`#319`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/319)

### Commits

*   Update **init**.py [`187747b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/187747bd2be024552451153ce0ad580f52df92e7)

## [v4.0.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.12...v4.0.0) - 2023-08-16

### Merged

*   Adds in Multi-Aperture Option [`#318`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/318)
*   V-R Polynomial Fit [`#312`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/312)
*   Major Improvements to Calculations [`#317`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/317)

### Commits

*   Update README.md [`0e85117`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/0e8511727c166c9e370e73e97060e2489c0eb284)
*   Update **init**.py [`7808622`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/78086224c2af297f557258a9a1ce163aac65c152)

## [v3.1.12](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.11...v3.1.12) - 2023-07-22

### Merged

*   Allows for the TESS text file [`#314`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/314)
*   Include Any Text File [`#316`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/316)
*   Updating Calculating Eclipse Number [`#315`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/315)
*   Combines TESS and AIJ into a Single Function [`#313`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/313)
*   Added in V-R Effective Temperature [`#311`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/311)
*   Reformat for to Make Testing Easier [`#310`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/310)

### Commits

*   Update **init**.py [`f3b766d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f3b766d01d73a9672450bc8d831e68c33c59053a)

## [v3.1.11](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.10...v3.1.11) - 2023-07-07

### Commits

*   Update **init**.py [`fc59da3`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/fc59da38b0ea9d387561e5e3253a5cd5b1e38d50)

## [v3.1.10](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.9...v3.1.10) - 2023-07-07

### Merged

*   Configure Tests to Work [`#309`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/309)
*   Create test\_apass.py [`#308`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/308)

## [v3.1.9](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.8...v3.1.9) - 2023-07-03

### Merged

*   Update entry points [`#306`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/306)
*   Exclude .fits files [`#305`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/305)

### Commits

*   Update **init**.py [`fac86de`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/fac86de4c0e251aa5542b0ef03e163d7e1a063a9)
*   Update **init**.py [`ae42770`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ae4277037c8008ddb3252762ead632d299de544e)
*   Update **init**.py [`4c0260f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/4c0260f71a6698a60b6387eb03a2c2ac330db20a)

## [v3.1.8](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.7...v3.1.8) - 2023-07-01

### Merged

*   Exclude fits files [`#304`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/304)
*   Excluding Folders from sdist [`#303`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/303)

### Commits

*   Update setup.cfg [`f735fa3`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f735fa380c0fb6cd9153094fdcf6fd190c7d86fe)
*   Update setup.cfg [`712d756`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/712d756bed9961aa044a67d18c09ae5df9bd01a8)
*   Update **init**.py [`9f883a5`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9f883a59197ff21cc41ce9ee53d0a84349ce9e6f)
*   Update **init**.py [`1393602`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/13936020bbc48a42d270749fcef94d04b10bd408)
*   Update **init**.py [`26f770d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/26f770d7a7b675e8544068fcf04a376e74006068)
*   Update **init**.py [`8db56e1`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8db56e1aaa79df934f7b61885af48b5535a9c7a0)
*   Update **init**.py [`a7e3f40`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a7e3f40da00e370efb5e05136a1190c1affbd0fa)
*   Create **init**.py [`c012380`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/c0123803efd50eee265aa7cf2cb48c46fcf5e1fe)
*   Create **init**.py [`49af631`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/49af631b693d230fcfbe0b3f7ef30794767aca88)

## [v3.1.7](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.6...v3.1.7) - 2023-06-30

### Merged

*   Not excluding folders [`#301`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/301)

### Commits

*   Create MANIFEST.in [`3fc9449`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/3fc9449d9fe2f664914710fe950956d24dbe7f75)
*   Update setup.cfg [`1f3374c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/1f3374cff3ca48be2fa6f69d17889837e5dac18e)
*   Update **init**.py [`38b1a10`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/38b1a108d0d26c40122fbebbe9aa6dfffb8dd54e)

## [v3.1.6](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.5...v3.1.6) - 2023-06-30

### Merged

*   Color Light Curve [`#300`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/300)
*   Fixed Warning [`#298`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/298)
*   Fixing Warning [`#297`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/297)
*   Minor Bug Fixes [`#296`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/296)
*   Adds in Numerous Example Figures/Files [`#295`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/295)
*   Add in O-C Documentation [`#294`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/294)
*   Floor and Ceiling were Backwards [`#293`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/293)
*   O'Connell Effect Doc [`#291`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/291)
*   Removing Conda Install Option [`#290`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/290)
*   Night Filters and Gaia Doc [`#288`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/288)
*   Add TESS and Comparison Star [`#287`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/287)
*   Add Find Minimum Documentation [`#286`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/286)
*   Minor Addons [`#285`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/285)
*   Finish IRAF Reduction Doc [`#284`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/284)
*   Location of IRAF File Update [`#283`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/283)
*   Update index.rst [`#282`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/282)
*   Create toolbox.rst [`#281`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/281)
*   Rename EB.rst to docs/EB.rst [`#280`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/280)
*   Create EB.rst [`#279`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/279)
*   Create pipeline.rst [`#278`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/278)
*   Create contributing.rst [`#277`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/277)
*   Update index.rst [`#276`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/276)
*   Reformatting Again [`#275`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/275)
*   Reformatting [`#271`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/271)
*   Update index.rst [`#274`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/274)
*   Rename Changelog File [`#273`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/273)
*   Rename changelog/CHANGELOG.md to CHANGELOG.md [`#272`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/272)
*   Comment Out [`#270`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/270)
*   Wrong Setup File [`#269`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/269)
*   Update and rename setup.py to setup.cfg [`#267`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/267)
*   Create pyproject.toml [`#268`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/268)
*   Update conf.py [`#266`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/266)
*   v3.1.5 [`#265`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/265)

### Commits

*   Example O-C Table [`fc3ec3a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/fc3ec3a532bbd3e151b935a0f8432df87ed0c2c9)
*   Additional Example Files [`8c6a557`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8c6a55708f2d0c384bce49eef8aa4ce54f52d36e)
*   Delete getting\_started.rst [`1e30bcb`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/1e30bcb4feeccd4f393d260b11fac8827110c796)
*   Add files via upload [`6540a9e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/6540a9ec9421b58abba960e83687b3aded2d0d1f)
*   Delete O-C\_paper\_table.txt [`4b1631f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/4b1631ff47994b9a23649d86e843acf6fc9e77f7)
*   O-C Latex Table for Papers [`4f39bd4`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/4f39bd43535e675b2ef56cbe27a215cb158e92ff)
*   Create setup.py [`e263869`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e2638691ee3c01a468f10a66daafd8231f4879f2)
*   Update **init**.py [`62fce1c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/62fce1c1826ec9779a5e2b7a0e901df66c958424)
*   Update and rename O-C\_paper\_table.tex to O-C\_paper\_table.txt [`b8a8de6`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b8a8de6182e447e4afaa5f0bdc325a0cf0b80a42)
*   Create module.rst [`7db4071`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7db40719477c702f75824382ef77ad8c8dfc6dc4)
*   Create class.rst [`aff5421`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/aff5421007e562164ad8df2051e8fd1e9d897aa6)
*   Create base.rst [`1185ccd`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/1185ccd956cfde8f88378f27eb8c3b0af8b76927)
*   Add files via upload [`ecbf139`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ecbf139611d2cf103e4749aad28c632971793fff)
*   Add files via upload [`234d62e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/234d62e18f19767f1f99601e99ca18acaf53835c)
*   Delete light\_curve\_ex.pdf [`7622c76`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7622c769141cb848375d612942590240ed63869d)
*   Delete color\_light\_curve\_ex.pdf [`f46e0e8`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f46e0e8467cc0742ee39338f2aa7465a0359ad5f)
*   Add files via upload [`61dde33`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/61dde3332654d4e1d613610a32cae70fd49af89a)
*   Delete OConnell\_plot.pdf [`3c3059e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/3c3059e48da9713edaf278bd90288425a3a4b2da)
*   Find Min Example [`7ed13f5`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7ed13f5c90c1b988fe7edeea76e80cc9bba7d249)

## [v3.1.5](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.4...v3.1.5) - 2023-06-23

### Merged

*   Update setup.cfg [`#264`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/264)

### Commits

*   Delete setup.cfg [`10be11b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/10be11b426518367499b0cfa8d336ac3ce161cfc)
*   Update **init**.py [`674f749`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/674f749e9cafd4ec0d0099dd0027d4e947615a02)

## [v3.1.4](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.3...v3.1.4) - 2023-06-23

### Merged

*   More Updates but Still Non-Functional [`#263`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/263)
*   Minor Changes and Ceiling Function [`#262`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/262)
*   Create setup.cfg [`#261`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/261)
*   v3.1.3 [`#260`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/260)

### Commits

*   Update **init**.py [`3d7fc3c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/3d7fc3c70b643538d9ddadd174a7de9bd0768397)

## [v3.1.3](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.2...v3.1.3) - 2023-06-20

### Merged

*   Update ci\_tests.yml [`#259`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/259)
*   Number of Pixels Determined [`#258`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/258)
*   Rogue Space [`#257`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/257)

### Commits

*   Update **init**.py [`25602f3`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/25602f38b11e86d7b571d6f7598e5226b9d83e58)
*   Update **init**.py [`a109c35`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a109c358990d9684f424691dcec1ce2c5cfb8385)

## [v3.1.2](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.1...v3.1.2) - 2023-06-20

### Commits

*   Update **init**.py [`9cddd12`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9cddd121c6ebca7804dcb84e725a57067bbae1bd)

## [v3.1.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.1.0...v3.1.1) - 2023-06-20

### Merged

*   More Accurate Magnitude Calculations [`#254`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/254)
*   Incorrect Pipeline Functionality [`#256`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/256)
*   Broken Badge [`#253`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/253)
*   Rename to Match the Code [`#252`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/252)
*   New Test Suite for Numerous Versions Across Platforms [`#251`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/251)
*   v3.1.0 [`#250`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/250)

### Commits

*   Delete python-package.yml [`a3e569a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a3e569a3e3f5e5e44808b8e881b201f08bdbbb11)
*   Delete python-app.yml [`0003448`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/0003448fa646b9c53f214e25167fad8dd5c9ed1f)

## [v3.1.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.0.0...v3.1.0) - 2023-06-18

### Merged

*   v3.1.0 [`#249`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/249)
*   UX Fixes [`#247`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/247)
*   If Statements Were Backwards [`#248`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/248)
*   v3.0.0 [`#246`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/246)
*   APASS Pipeline Ability [`#245`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/245)
*   Pipeline Ability [`#244`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/244)
*   New Values for SARA Telescopes [`#243`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/243)
*   Minor Output Updates [`#242`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/242)
*   Includes Pipeline Commands [`#240`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/240)
*   v3.0.0 [`#239`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/239)

## [v3.0.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v3.0.0-alpha.1...v3.0.0) - 2023-06-17

### Merged

*   Incorrect Time Threshold [`#238`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/238)
*   Automates Reduction Completely for BSUO Pipeline [`#237`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/237)
*   Command Updates [`#236`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/236)
*   Infinite Loop Error [`#234`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/234)
*   Minor Updates to Variables [`#235`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/235)
*   More Pipeline Commands [`#232`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/232)
*   More Arguments [`#233`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/233)
*   Pipeline Capabilities [`#231`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/231)
*   Pipeline Command [`#230`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/230)
*   Create pipeline.py [`#229`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/229)

### Commits

*   Update IRAF\_Reduction.py [`b811431`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b811431b2113621f293065ea19f9c8a560a6d2fc)
*   Delete pipeline.py [`71c7d7c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/71c7d7ccacd2ccc1793538c2aa0b6fa0905a307e)
*   Update setup.py [`76394ea`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/76394ea6cc77d3102bad868f0d80010b40eedc33)
*   Update setup.py [`14e417a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/14e417a406f21f5eadceffc3d8f973f5e61d62b0)
*   Update setup.py [`352b843`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/352b84379c444a0a653ddeab9e0e9561bd49fd67)
*   Update setup.py [`bfe8462`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/bfe84626625fcdcf6efe5fcd24f2197eb4e36ab6)
*   Update **init**.py [`d2893cf`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d2893cf719ed77c0fa678e3b3504ca4924c3879f)
*   Update **init**.py [`5d393c4`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5d393c4d0e4f595d35d2c702433e52b2930ea44a)
*   Update **init**.py [`9255acf`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9255acfd11ca659b702efb4c0378763a5920871f)
*   Update setup.py [`c2e0e5a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/c2e0e5a6ee04698909b1bd7618a861ed8e1cc554)
*   Update **init**.py [`782f88d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/782f88def1aab0f49b5b21841e6be3806ccc0aee)
*   Update **init**.py [`187e4c8`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/187e4c8f30b872c22ce4838bd62c92c9e0d6da81)
*   Update setup.py [`b1b96b0`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b1b96b04f9459df9e12e86b6c535c6bbdfa82331)
*   Update setup.py [`fa0a943`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/fa0a943bfb46d251669881a102a692d53f218bbb)
*   Missing Comma [`7b9774a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7b9774a07ee5a51dccfc199d27eb63da2b4486b0)
*   Update **init**.py [`28e24a4`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/28e24a4d46065ddbe8c08c985f201bd2eb9ee16b)

## [v3.0.0-alpha.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.5-alpha.10...v3.0.0-alpha.1) - 2023-06-15

### Merged

*   Output Update [`#228`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/228)
*   Command Line Argument Variables Added [`#227`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/227)
*   Allow Command Line Arguments [`#226`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/226)
*   Create pipeline.py [`#225`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/225)
*   Adds in Pipeline Capabilities [`#224`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/224)
*   v2.8.4a11 [`#223`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/223)
*   Minor Updates and Commented Problem Line [`#222`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/222)
*   Update Package Versions [`#221`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/221)
*   Minor Formatting Updates [`#219`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/219)
*   Matplotlib Update [`#220`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/220)

### Commits

*   Update **init**.py [`9738288`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/97382889802638a066c7df5a1b35752e76ebcd40)
*   Update **init**.py [`46aa4fe`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/46aa4fe5079d8743bad35d55767398636ec29dd2)

## [v2.8.5-alpha.10](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.5-alpha.5...v2.8.5-alpha.10) - 2023-06-13

### Merged

*   Using an Older Version in Last Update [`#216`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/216)
*   Adds Weights to Least Squares Fit and Minor Fixes [`#214`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/214)
*   Update **init**.py [`#215`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/215)
*   Compiling Error [`#213`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/213)
*   Started Work on Using Comparisons [`#212`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/212)
*   Update Function Name and Plotting [`#211`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/211)
*   Multi-Aperture Photometry for a Single Object [`#210`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/210)
*   More Accurate Background Calculations [`#209`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/209)
*   New Calculations [`#208`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/208)
*   Automatic Limits for Overlay [`#205`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/205)
*   Update index.rst [`#203`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/203)
*   Create getting\_started.rst [`#201`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/201)
*   Create license.rst [`#202`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/202)
*   Update index.rst [`#200`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/200)
*   Create installation.rst [`#199`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/199)
*   Delete jekyll-gh-pages.yml [`#198`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/198)
*   Many Errors Before Calculations [`#197`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/197)
*   Create .slugignore [`#196`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/196)
*   v2.8.4-alpha.7 [`#195`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/195)
*   Menu Options and Format [`#194`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/194)
*   Move to the Next Day [`#193`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/193)
*   First Attempt at Multi-Aperture Photometry [`#191`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/191)
*   Header and Overscan/Trim Fixes [`#190`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/190)
*   Hyperlink Updates [`#189`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/189)
*   BJD to HJD Conversion [`#188`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/188)
*   Add Files for Django/Heroku [`#187`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/187)
*   Line was not Commented Out [`#186`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/186)

### Commits

*   Create conf.py [`155e8fa`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/155e8fa1000d4485d82c1a6582bd16020bc56e09)
*   Delete settings.py [`b87a88e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b87a88ea4157df3c756e544c338a0818f74718ce)
*   Create index.rst [`31df806`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/31df8064563caf3aa162dc63a986048d2c77f8d4)
*   Create .readthedocs.yml [`d7c388f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d7c388fad3230cb581c762438aecc7fb2066b485)
*   Update .readthedocs.yml [`37c846f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/37c846fd5d258ab5313dbe40245cb8e60439caa1)
*   Update .readthedocs.yml [`1edf7a8`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/1edf7a89b734d7130c464a74062ed81230e28db0)
*   Create changelog.rst [`497e65b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/497e65b8a2e489dbe5530dff686dbc2627475c6e)
*   Delete api.rst [`ac5991b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ac5991bb211fd2c67540d682a9bca57866568908)
*   Create api.rst [`d8c665f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d8c665f967825914dc599ec788897941a6c923ef)
*   Update requirements.txt [`5c9d854`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5c9d854b0ed439cf192c63c4431512612eb25204)
*   Update .readthedocs.yml [`5c74f50`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5c74f50f25b4919b3e96895d949516a1363e34e0)
*   Update conf.py [`2345e57`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2345e57c0056e92c499b384a836fb3e5956c988b)
*   Delete .slugignore [`117fb51`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/117fb5146a946ce954d53e8ed4bfbae09436c718)
*   Update conf.py [`6c5057a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/6c5057a54665a76aa2da06c821f13dfbd999a3d7)
*   Update conf.py [`423ad36`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/423ad3607e4d4970b6fec57a662b79dcdf738b57)
*   Update conf.py [`98de55a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/98de55a8683507bb167a81a3e7adce1e40bc6766)
*   Update .readthedocs.yml [`a79f443`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a79f4432cb92fb6760cd03704f4e4b2dfd984c59)
*   Update .readthedocs.yml [`5f1d337`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5f1d337facfc13a2592498a2f1d817785dca7f3c)
*   Update .readthedocs.yml [`b56e5d2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b56e5d2b2ef797679e8c52582f24973c583b1b34)
*   Update runtime.txt [`0210141`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/021014199a155f4ddeeb86a4f0623be7248b739a)
*   Update runtime.txt [`dff0d4e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/dff0d4ed5853db0a9436a1df2082b83e4671ac89)
*   Update runtime.txt [`0363971`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/0363971493f62b66fd64196067ec362dc67a018b)
*   Update README.md [`e921181`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e92118109c3c0c4471bd36d0e1541a14067b090e)
*   Delete runtime.txt [`f0ec1ac`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f0ec1ac4d0462892549afee64151a4eed319e412)
*   Delete Procfile [`eb6b03b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/eb6b03bd48e673ea01b2ca9ff193b77be39865b4)
*   Rename docs/source/index.rst to docs/index.rst [`bcf220d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/bcf220db87cc49caaa90b9f8e143330675f7cc6c)
*   Rename docs/source/conf.py to docs/conf.py [`c163a5c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/c163a5c92ba0b1302bab209b51921b076300827d)
*   Rename docs/conf.py to docs/source/conf.py [`a440ae2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a440ae2ce8367d9c58dfa4a387576b0f3a087d25)
*   Rename docs/index.rst to docs/source/index.rst [`e683c99`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e683c9907398c3fb54b7f414c06d21bc15e0bc75)
*   Rename docs/source/index.rst to docs/index.rst [`36690fc`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/36690fc70a946af1c0223a5cd81e47f582e6b745)
*   Rename docs/source/conf.py to docs/conf.py [`a5696e2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a5696e27a2b742f21bd06d5eb929496f71f4c24b)
*   Rename README.rst to README.md [`61d92c0`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/61d92c01cd6eb35b498c0228f4c27bd0f6980d94)
*   Rename README.md to README.rst [`5a9a3c8`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5a9a3c85c16c5768fcf773da71e98dacd885e460)
*   Example Master Calibration Images [`995c4d5`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/995c4d556cd9faef7afa7aed03f162c710172185)

## [v2.8.5-alpha.5](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.4-alpha12...v2.8.5-alpha.5) - 2023-04-27

## [v2.8.4-alpha12](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.4-alpha.11...v2.8.4-alpha12) - 2023-06-15

### Merged

*   v2.8.4a11 [`#223`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/223)
*   Minor Updates and Commented Problem Line [`#222`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/222)
*   Update Package Versions [`#221`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/221)

### Commits

*   Update **init**.py [`9738288`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/97382889802638a066c7df5a1b35752e76ebcd40)

## [v2.8.4-alpha.11](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.4-alpha.10...v2.8.4-alpha.11) - 2023-06-14

### Merged

*   Minor Formatting Updates [`#219`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/219)
*   Matplotlib Update [`#220`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/220)

### Commits

*   Update **init**.py [`46aa4fe`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/46aa4fe5079d8743bad35d55767398636ec29dd2)

## [v2.8.4-alpha.10](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.4-alpha.9...v2.8.4-alpha.10) - 2023-06-13

### Merged

*   Using an Older Version in Last Update [`#216`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/216)

### Commits

*   Update **init**.py [`f92df11`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f92df111cc4b1fd4fa4f9f8d7abdc9d13c8e35bb)

## [v2.8.4-alpha.9](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.4-alpha.8...v2.8.4-alpha.9) - 2023-06-12

### Merged

*   Adds Weights to Least Squares Fit and Minor Fixes [`#214`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/214)
*   Update **init**.py [`#215`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/215)
*   Compiling Error [`#213`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/213)
*   Started Work on Using Comparisons [`#212`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/212)
*   Update Function Name and Plotting [`#211`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/211)
*   Multi-Aperture Photometry for a Single Object [`#210`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/210)
*   More Accurate Background Calculations [`#209`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/209)
*   New Calculations [`#208`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/208)

### Commits

*   Update .readthedocs.yml [`1edf7a8`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/1edf7a89b734d7130c464a74062ed81230e28db0)
*   Create changelog.rst [`497e65b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/497e65b8a2e489dbe5530dff686dbc2627475c6e)
*   Update conf.py [`423ad36`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/423ad3607e4d4970b6fec57a662b79dcdf738b57)
*   Rename docs/source/index.rst to docs/index.rst [`bcf220d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/bcf220db87cc49caaa90b9f8e143330675f7cc6c)
*   Rename docs/source/conf.py to docs/conf.py [`c163a5c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/c163a5c92ba0b1302bab209b51921b076300827d)
*   Rename docs/conf.py to docs/source/conf.py [`a440ae2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a440ae2ce8367d9c58dfa4a387576b0f3a087d25)
*   Rename docs/index.rst to docs/source/index.rst [`e683c99`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e683c9907398c3fb54b7f414c06d21bc15e0bc75)

## [v2.8.4-alpha.8](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.4-alpha.7...v2.8.4-alpha.8) - 2023-05-19

### Merged

*   Automatic Limits for Overlay [`#205`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/205)
*   Update index.rst [`#203`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/203)
*   Create getting\_started.rst [`#201`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/201)
*   Create license.rst [`#202`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/202)
*   Update index.rst [`#200`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/200)
*   Create installation.rst [`#199`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/199)
*   Delete jekyll-gh-pages.yml [`#198`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/198)
*   Many Errors Before Calculations [`#197`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/197)
*   Create .slugignore [`#196`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/196)
*   v2.8.4-alpha.7 [`#195`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/195)

### Commits

*   Create conf.py [`155e8fa`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/155e8fa1000d4485d82c1a6582bd16020bc56e09)
*   Delete settings.py [`b87a88e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b87a88ea4157df3c756e544c338a0818f74718ce)
*   Create index.rst [`31df806`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/31df8064563caf3aa162dc63a986048d2c77f8d4)
*   Create .readthedocs.yml [`d7c388f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d7c388fad3230cb581c762438aecc7fb2066b485)
*   Update .readthedocs.yml [`37c846f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/37c846fd5d258ab5313dbe40245cb8e60439caa1)
*   Delete api.rst [`ac5991b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ac5991bb211fd2c67540d682a9bca57866568908)
*   Create api.rst [`d8c665f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d8c665f967825914dc599ec788897941a6c923ef)
*   Update requirements.txt [`5c9d854`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5c9d854b0ed439cf192c63c4431512612eb25204)
*   Update .readthedocs.yml [`5c74f50`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5c74f50f25b4919b3e96895d949516a1363e34e0)
*   Update conf.py [`2345e57`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2345e57c0056e92c499b384a836fb3e5956c988b)
*   Delete .slugignore [`117fb51`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/117fb5146a946ce954d53e8ed4bfbae09436c718)
*   Update conf.py [`6c5057a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/6c5057a54665a76aa2da06c821f13dfbd999a3d7)
*   Update conf.py [`98de55a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/98de55a8683507bb167a81a3e7adce1e40bc6766)
*   Update **init**.py [`e3d7856`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e3d7856aad349399f763b2062d8509c7758b99f5)
*   Update .readthedocs.yml [`a79f443`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a79f4432cb92fb6760cd03704f4e4b2dfd984c59)
*   Update .readthedocs.yml [`5f1d337`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5f1d337facfc13a2592498a2f1d817785dca7f3c)
*   Update .readthedocs.yml [`b56e5d2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b56e5d2b2ef797679e8c52582f24973c583b1b34)
*   Update runtime.txt [`0210141`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/021014199a155f4ddeeb86a4f0623be7248b739a)
*   Update README.md [`e921181`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e92118109c3c0c4471bd36d0e1541a14067b090e)
*   Delete runtime.txt [`f0ec1ac`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f0ec1ac4d0462892549afee64151a4eed319e412)
*   Delete Procfile [`eb6b03b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/eb6b03bd48e673ea01b2ca9ff193b77be39865b4)
*   Rename docs/source/index.rst to docs/index.rst [`36690fc`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/36690fc70a946af1c0223a5cd81e47f582e6b745)
*   Rename docs/source/conf.py to docs/conf.py [`a5696e2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a5696e27a2b742f21bd06d5eb929496f71f4c24b)
*   Rename README.rst to README.md [`61d92c0`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/61d92c01cd6eb35b498c0228f4c27bd0f6980d94)
*   Rename README.md to README.rst [`5a9a3c8`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5a9a3c85c16c5768fcf773da71e98dacd885e460)

## [v2.8.4-alpha.7](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.4-alpha.6...v2.8.4-alpha.7) - 2023-05-14

### Merged

*   Menu Options and Format [`#194`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/194)
*   Move to the Next Day [`#193`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/193)
*   First Attempt at Multi-Aperture Photometry [`#191`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/191)
*   Header and Overscan/Trim Fixes [`#190`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/190)
*   Hyperlink Updates [`#189`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/189)
*   BJD to HJD Conversion [`#188`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/188)
*   Add Files for Django/Heroku [`#187`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/187)

### Commits

*   Update **init**.py [`ea61961`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ea61961cc9e32b486737137b96c1b4a88aec15a7)
*   Update runtime.txt [`dff0d4e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/dff0d4ed5853db0a9436a1df2082b83e4671ac89)
*   Update runtime.txt [`0363971`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/0363971493f62b66fd64196067ec362dc67a018b)
*   Example Master Calibration Images [`995c4d5`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/995c4d556cd9faef7afa7aed03f162c710172185)

## [v2.8.4-alpha.6](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.4-alpha.5...v2.8.4-alpha.6) - 2023-04-27

## [v2.8.4-alpha.5](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.4-alpha.4...v2.8.4-alpha.5) - 2023-04-27

### Merged

*   Line was not Commented Out [`#186`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/186)
*   Effective Temperatures Added [`#185`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/185)
*   Switch Round to Floor [`#184`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/184)
*   Allows for TESS Text File to be Used [`#183`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/183)

### Commits

*   Update **init**.py [`871d31b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/871d31ba014f94c9bb844e9da85cae83b59993e5)
*   Update **init**.py [`bae0ee0`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/bae0ee028ce257c4e6625dfe677e262ccc4f3919)

## [v2.8.4-alpha.4](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.4-alpha.3...v2.8.4-alpha.4) - 2023-04-25

### Merged

*   Testing Import Package was not Commented [`#182`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/182)
*   v2.8.4-alpha.3 [`#181`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/181)
*   Example Minimum File [`#180`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/180)

### Commits

*   Adds TESS CCD/Camera Info [`617e963`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/617e963a5876d2ad264617b2c52dea7ecf0b9513)
*   Update **init**.py [`bea5f8e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/bea5f8e0fe26ce11bf01492ae57d98b53b2b1b3b)

## [v2.8.4-alpha.3](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.4-alpha.2...v2.8.4-alpha.3) - 2023-04-24

### Merged

*   Update **init**.py [`#179`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/179)
*   Redo Package Data [`#178`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/178)
*   Rename tests/test\_OC\_plot.py to EclipsingBinaries/tests/test\_OC\_plot.py [`#177`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/177)
*   Rename tests/**init**.py to EclipsingBinaries/test/**init**.py [`#176`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/176)

### Commits

*   Move examples folder into main folder [`a1c7c08`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a1c7c089b2675b53ab646aede9c2ef90bccb1c6d)

## [v2.8.4-alpha.2](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.4-alpha.1...v2.8.4-alpha.2) - 2023-04-20

### Merged

*   Changing the Python Dorectory [`#175`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/175)

### Commits

*   Update **init**.py [`241de51`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/241de51086f05f429d137ce6deaf13210e2fb1a1)

## [v2.8.4-alpha.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.3...v2.8.4-alpha.1) - 2023-04-20

### Merged

*   Ability to Add the Tests Folder [`#174`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/174)
*   Adds Gain and Read Noise for TESS CCD's [`#173`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/173)
*   Create jekyll-gh-pages.yml [`#172`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/172)
*   Removed some Commented Lines [`#171`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/171)
*   Example Light Curve Files [`#170`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/170)
*   Fixed Commented Lines [`#169`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/169)
*   Testing Calibration Master Creations [`#168`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/168)
*   Update and rename test.txt to purpose.txt [`#167`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/167)
*   Added Calibration Data for Testing [`#166`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/166)
*   Adds the Gain as an Output [`#164`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/164)
*   v2.8.3 [`#163`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/163)

### Commits

*   Create test.txt [`9139904`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/913990481e08aa68b33710c11d10222cc7cd75c8)

## [v2.8.3](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.2...v2.8.3) - 2023-04-05

### Merged

*   More Accurate Magnitude Gathering [`#162`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/162)
*   Minor Updates [`#161`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/161)
*   v2.8.1 [`#160`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/160)

## [v2.8.2](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.1...v2.8.2) - 2023-04-05

### Merged

*   Update Gaia Import [`#159`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/159)

## [v2.8.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.8.0...v2.8.1) - 2023-04-05

### Merged

*   Darks are no Longer Required [`#158`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/158)
*   v2.8.0 [`#157`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/157)

## [v2.8.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.10-alpha2...v2.8.0) - 2023-04-04

### Merged

*   Fixed Import Syntax Error [`#155`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/155)
*   Import Updates [`#154`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/154)
*   Wrong Import Commented Out [`#153`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/153)
*   Wrong Set of Imports [`#152`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/152)
*   Move Functions from apss.py [`#151`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/151)
*   Updated for TESS Magnitudes [`#149`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/149)
*   List Querying of Gaia [`#150`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/150)
*   Allow for User Entered Values Like Gain [`#148`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/148)
*   Misspelled Function Name [`#145`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/145)
*   Must add this file [`#144`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/144)
*   Wrong Word [`#143`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/143)
*   Move the tests folder [`#141`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/141)
*   Tests Folder was Not Showing Up [`#140`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/140)

### Commits

*   Update **init**.py [`b24e1e4`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b24e1e4e7c7ba6a4997a7c8d4009a2625a7bb368)
*   Update **init**.py [`8b1f048`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8b1f048f2168c0432a52a8c8382825bdc858863f)
*   Update **init**.py [`eb74de9`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/eb74de9554cb91d62af253d4f0dd3fedc184191c)
*   Update **init**.py [`d6d8a1f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d6d8a1f20da49c96244323e1344947aa952cb8da)
*   Update **init**.py [`75aed21`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/75aed21e82a83fdbd0ebed5aeeb90463174c44a0)
*   Update **init**.py [`82925a7`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/82925a7cbf485eab34c7363604294167b8da73be)
*   Update **init**.py [`6952138`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/69521387d3899f533fc866b1497a8f4cb69a1433)
*   Update **init**.py [`b012f4d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b012f4dc4c7252f88147f279aa59c75f2c20d1a4)
*   Update **init**.py [`2a48811`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2a488116651603f289aeb522f4d61ad9dc09bde6)
*   Update **init**.py [`76b152d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/76b152d8ba1d53473e0444f0efe3e10427a19982)

## [v2.7.10-alpha2](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.10-alpha1...v2.7.10-alpha2) - 2023-04-02

### Merged

*   Development Status Correction [`#139`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/139)

### Commits

*   Update **init**.py [`55df9b1`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/55df9b174a68fd8f2284f5032ce001e6f1c9efcf)

## [v2.7.10-alpha1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.10-alpha.7...v2.7.10-alpha1) - 2023-04-02

## [v2.7.10-alpha.7](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.10-alpha.6...v2.7.10-alpha.7) - 2023-04-02

### Merged

*   Misspelled Function Name [`#145`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/145)

### Commits

*   Update **init**.py [`b24e1e4`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b24e1e4e7c7ba6a4997a7c8d4009a2625a7bb368)
*   Update **init**.py [`8b1f048`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8b1f048f2168c0432a52a8c8382825bdc858863f)
*   Update **init**.py [`eb74de9`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/eb74de9554cb91d62af253d4f0dd3fedc184191c)

## [v2.7.10-alpha.6](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.10-alpha.5...v2.7.10-alpha.6) - 2023-04-02

### Merged

*   Must add this file [`#144`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/144)
*   Wrong Word [`#143`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/143)

### Commits

*   Update **init**.py [`d6d8a1f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d6d8a1f20da49c96244323e1344947aa952cb8da)

## [v2.7.10-alpha.5](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.10-alpha.4...v2.7.10-alpha.5) - 2023-04-02

### Merged

*   Move the tests folder [`#141`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/141)

### Commits

*   Update **init**.py [`75aed21`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/75aed21e82a83fdbd0ebed5aeeb90463174c44a0)

## [v2.7.10-alpha.4](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.10-alpha.3...v2.7.10-alpha.4) - 2023-04-02

### Merged

*   Tests Folder was Not Showing Up [`#140`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/140)

### Commits

*   Update **init**.py [`82925a7`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/82925a7cbf485eab34c7363604294167b8da73be)

## [v2.7.10-alpha.3](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.9...v2.7.10-alpha.3) - 2023-04-02

### Merged

*   Development Status Correction [`#139`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/139)
*   Creating a Test File [`#138`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/138)
*   v2.7.10-alpha1 [`#137`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/137)
*   v2.7.9 [`#136`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/136)
*   Added PyTest Requirement [`#135`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/135)

### Commits

*   Update **init**.py [`6952138`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/69521387d3899f533fc866b1497a8f4cb69a1433)
*   Update **init**.py [`b012f4d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b012f4dc4c7252f88147f279aa59c75f2c20d1a4)
*   Update **init**.py [`2a48811`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2a488116651603f289aeb522f4d61ad9dc09bde6)
*   Update **init**.py [`76b152d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/76b152d8ba1d53473e0444f0efe3e10427a19982)
*   Update **init**.py [`55df9b1`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/55df9b174a68fd8f2284f5032ce001e6f1c9efcf)

## [v2.7.9](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.8...v2.7.9) - 2023-03-23

### Merged

*   Allows for Downloading Specific Sectors [`#132`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/132)
*   Fixed File Path Error [`#131`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/131)

## [v2.7.8](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.7...v2.7.8) - 2023-03-23

### Merged

*   Commented Line was not Commented [`#130`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/130)
*   v2.7.7 [`#124`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/124)

### Commits

*   Updates [`868f2c6`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/868f2c62505bb21ee9c85f7e8457775adda46e91)

## [v2.7.7](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.6...v2.7.7) - 2023-03-17

### Commits

*   Importation of the `apass.py` file was incorrectly done and caused an error upon loading the package entirely. [`0f7495b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/0f7495b1ff9597733b7161ab218269f089eabd93)

## [v2.7.6](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.5...v2.7.6) - 2023-03-16

### Merged

*   Commented Variable [`#123`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/123)

## [v2.7.5](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.4...v2.7.5) - 2023-03-16

### Merged

*   Importing File Issue [`#122`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/122)

## [v2.7.4](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.3...v2.7.4) - 2023-03-16

### Merged

*   Fixed Small Error in Plotting [`#121`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/121)

## [v2.7.3](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.2...v2.7.3) - 2023-03-16

### Merged

*   Size of the Cutouts [`#120`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/120)

## [v2.7.2](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.1...v2.7.2) - 2023-03-16

### Merged

*   v2.7.2 [`#119`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/119)
*   Error with String and Floats [`#118`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/118)
*   Update Instructions [`#117`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/117)
*   v2.7.1 [`#116`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/116)

### Commits

*   Update README.md [`665dd23`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/665dd2329db0c4f93079946d4d0b38e5aa1a51af)
*   Update README.md [`a184bef`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a184bef3b3856e42052c7d9aaaa051c77eefb252)
*   Update README.md [`e22369e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e22369e7507863c6bab94caab0fa09f99bc9bb4c)

## [v2.7.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.7.0...v2.7.1) - 2023-03-11

### Merged

*   v2.7.1 [`#115`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/115)
*   Change Output Link [`#114`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/114)
*   Output Label and Figure Changes [`#113`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/113)
*   Output and Latex Fixes [`#112`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/112)
*   2 Number 8's [`#111`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/111)

## [v2.7.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.6.3...v2.7.0) - 2023-03-09

### Merged

*   Dependency for Gaia Data [`#110`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/110)
*   Added Gaia Data Search [`#109`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/109)
*   Query Gaia Data [`#108`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/108)

### Commits

*   Update README.md [`35028a5`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/35028a5dfbe7bb5d04244fb24d4ceff3e212bcae)
*   Update **init**.py [`0da229a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/0da229a8b866f3aa398ab519106bcff435b1988e)
*   Update README.md [`386355d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/386355d2f805140c4456d7da3b703dfb3befe33a)

## [v2.6.3](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.6.2...v2.6.3) - 2023-03-08

### Merged

*   Comment Line [`#107`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/107)
*   v2.6.2 [`#106`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/106)

### Commits

*   Update **init**.py [`f45e52f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f45e52f734a20f0dabf54c71bc242ca15f257323)

## [v2.6.2](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.6.1...v2.6.2) - 2023-03-08

### Merged

*   Target Object in Overlay [`#105`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/105)
*   Overscan Region Fix [`#104`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/104)
*   Usability Updates [`#103`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/103)
*   Implement Kwee van Woerden Method [`#102`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/102)
*   Minor Update [`#101`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/101)
*   Minor Update [`#100`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/100)
*   Minor Update [`#99`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/99)

### Commits

*   Update **init**.py [`715bb54`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/715bb54af926bd4136026009e84180f6d0b883b2)

## [v2.6.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.6.0...v2.6.1) - 2023-02-23

### Merged

*   Incorrect Prompts [`#96`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/96)
*   Clarity for Initial Folder Input [`#95`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/95)
*   Default Program [`#94`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/94)
*   v2.6.0 [`#93`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/93)

### Commits

*   Update **init**.py [`8e4e698`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8e4e69838fbc0ed879e17d441a22f0e0857124bb)

## [v2.6.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.5.4...v2.6.0) - 2023-02-19

### Merged

*   Removed Unused Imports [`#92`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/92)
*   Draggable Legend and Minor Changes [`#91`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/91)
*   Clarity of R Filter Request File [`#90`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/90)
*   v2.5.4 [`#89`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/89)

### Commits

*   Update **init**.py [`87d3e1a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/87d3e1a16e94cbcd9b509f559a31c9301c45c6a3)
*   Update README.md [`96fc90e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/96fc90ed247902b62dd1b211c84947cc6c63b183)

## [v2.5.4](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.5.3...v2.5.4) - 2023-02-13

### Merged

*   Removed Random Print Statement [`#88`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/88)
*   Prompt Update [`#87`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/87)
*   Change in Prompts and File Pathways [`#86`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/86)
*   v2.5.3 [`#85`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/85)

### Commits

*   Update **init**.py [`c8c97e2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/c8c97e2374bae99f019dca5705823ae937595ea7)

## [v2.5.3](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.5.2...v2.5.3) - 2023-02-10

### Merged

*   Minor Updates and Usage [`#83`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/83)

### Commits

*   Update **init**.py [`f027024`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f027024dc083f79c19b7094480e76398061e0ea1)

## [v2.5.2](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.5.1...v2.5.2) - 2023-02-09

### Merged

*   Missing Commented Line [`#82`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/82)
*   APASS Description Update [`#81`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/81)
*   v2.5.1 [`#80`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/80)

### Commits

*   Update **init**.py [`4a4298e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/4a4298e7727bf27639fca86cc013bac7892e170e)

## [v2.5.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.5.0...v2.5.1) - 2023-02-04

### Merged

*   Bug With No Output in RADEC Files [`#79`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/79)

### Commits

*   Update **init**.py [`e01063e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e01063e2c1afa00d646293f317e4064f30d8e360)

## [v2.5.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.4.1...v2.5.0) - 2023-02-04

### Merged

*   Complete Overhaul [`#78`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/78)
*   Updated Prompt [`#76`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/76)

### Commits

*   Update **init**.py [`6310665`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/631066520a345bbd7da0f9284870e7e51dc34e8f)
*   Update **init**.py [`8456f26`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8456f261ae4b3fd004635080797a1fa54379fabe)

## [v2.4.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.4.0...v2.4.1) - 2023-02-02

### Merged

*   Latex Output Update [`#75`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/75)
*   v2.4.0 [`#74`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/74)

### Commits

*   Update **init**.py [`02f094c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/02f094c5ec1fc4526d3f8eadb9df5faf901ad1ce)

## [v2.4.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.3.1...v2.4.0) - 2023-02-01

### Merged

*   Update CHANGELOG.md [`#72`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/72)

### Commits

*   Big Fix to All Data [`c73b2a5`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/c73b2a5b5b241384c93465f3be9f030a1dec3eef)
*   Update **init**.py [`667e4e2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/667e4e2f4a39c2518a9b2ffcac70833f6d082b3a)
*   Update README.md [`9576b29`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9576b299ca273b6e5a9764184ff9881f2b6749cb)

## [v2.3.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.3.0...v2.3.1) - 2023-01-30

### Commits

*   Update **init**.py [`8978d44`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8978d44bc2928290c1212e0df0c9bd73d31d6e58)
*   Update tess\_data\_search.py [`428c000`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/428c000e0ba3eb888882b718f6f7979194793c0d)
*   Update README.md [`09ea168`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/09ea168397ec9021320d17ac9a1eae46e4b5b49c)

## [v2.3.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.2.1...v2.3.0) - 2023-01-30

### Merged

*   Added tess\_data\_search [`#70`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/70)
*   Changes to Downloading the Zip Files [`#69`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/69)

### Commits

*   Update **init**.py [`a5480f6`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a5480f6aca596793bff685c96ab905db9c6db76e)

## [v2.2.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.2.0...v2.2.1) - 2023-01-30

### Commits

*   Update **init**.py [`bb52040`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/bb52040b4fa644a065d32f7a44055709b23f884d)

## [v2.2.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.1.10...v2.2.0) - 2023-01-30

### Merged

*   Prompt Edits [`#68`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/68)
*   Spacing Changes [`#67`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/67)
*   Prompt Updates [`#66`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/66)
*   Input Prompts and Print Updates [`#65`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/65)
*   Prompts and Print Updates [`#64`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/64)
*   Prompts and Print Updates [`#63`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/63)
*   Print Updates [`#62`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/62)
*   Outputs Updated [`#61`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/61)
*   Input Command Changes [`#60`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/60)

## [v2.1.10](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.1.9...v2.1.10) - 2023-01-26

### Merged

*   OC\_Plot Calling Wrong Function [`#59`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/59)
*   Seaborn Dependency [`#58`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/58)
*   More Badges [`#57`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/57)

### Commits

*   Update LICENSE [`3bd072a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/3bd072ac99af7ea4aeed4cb1268e5509f57f121e)
*   Update **init**.py [`28bcf12`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/28bcf1221d7f95d677c11c78768eb3cabb5c31ea)

## [v2.1.9](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.1.8...v2.1.9) - 2023-01-26

### Merged

*   Update setup.py [`#56`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/56)

### Commits

*   Update python-publish.yml [`4087888`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/4087888d3284d162992358be997d872a1bc9dd36)

## [v2.1.8](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.1.7...v2.1.8) - 2023-01-26

### Commits

*   Minor Edits [`f7e58f2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f7e58f29578a1c9ef30a668a6456da9c866329cb)

## [v2.1.7](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.1.6...v2.1.7) - 2023-01-26

### Merged

*   Adding Version Checking [`#55`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/55)

### Commits

*   Update LICENSE [`5192573`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5192573fba62dcf25b33a33940b2c2fbb52ff3d4)
*   Update **init**.py [`045d392`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/045d392878bac3699f9779510181e58ebf26da55)

## [v2.1.6](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.1.5...v2.1.6) - 2023-01-26

### Merged

*   Seaborn Dependency [`#54`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/54)
*   PyPi Update [`#53`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/53)

### Commits

*   Update README.md [`90e285a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/90e285a13a614c692822fce77cf46c8ba2c20365)
*   Update setup.py [`89249fa`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/89249fad3ba3992c41ae0e8c25ee71cf34a71844)

## [v2.1.5](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.1.4...v2.1.5) - 2023-01-26

### Commits

*   Update setup.py [`bc4cdc7`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/bc4cdc7b7d1e5a4f28d8b91e50d06f7ac3d95eff)

## [v2.1.4](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.1.3...v2.1.4) - 2023-01-26

### Merged

*   Changed the Minimum Required Python [`#52`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/52)
*   Added line to Upgrade Wheel [`#51`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/51)

## [v2.1.3](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v2.1.0...v2.1.3) - 2023-01-25

### Merged

*   Create python-publish.yml [`#50`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/50)
*   Update for PyPi [`#49`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/49)

### Commits

*   Delete requirements.txt [`8334426`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8334426dd2a8917354af1b44ba676e2946084547)
*   Update README.md [`b0eeed0`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b0eeed075577db67dd4115c17924c929dfb05e28)
*   Add files via upload [`2d9f336`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2d9f3362c531553c3796dda17c1c03594716c8af)
*   Rename vseq\_updated.py to EclipsingBinaries/vseq\_updated.py [`f3ea6de`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f3ea6ded37042847d79510b14f9c2e36d05ce292)
*   Rename tesscut.py to EclipsingBinaries/tesscut.py [`5be4fe3`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5be4fe3377129465a9af16aaa19fcd880f75b0da)
*   Rename tess\_data\_search.py to EclipsingBinaries/tess\_data\_search.py [`b896d8a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b896d8ae669ecbde1d8c82b9730f02b76cb93bb9)
*   Rename menu.py to EclipsingBinaries/menu.py [`ce50db2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ce50db23b3dbb8551dd9b8d6593a7975c3a25298)
*   Rename color\_light\_curve.py to EclipsingBinaries/color\_light\_curve.py [`2aa00e1`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2aa00e1d2aa86422020be2fef8e464cb739a6e5e)
*   Rename apass.py to EclipsingBinaries/apass.py [`7602b44`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7602b44b7190ff6dc384de836e5f7c4a6df7e8c3)
*   Rename OConnell.py to EclipsingBinaries/OConnell.py [`254454d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/254454d08af32a39e0838dded81c6de0aa7b89e2)
*   Rename OC\_plot.py to EclipsingBinaries/OC\_plot.py [`3e0f516`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/3e0f5165f7eb52391e0f3bdbf305dbf3e3fd1a0f)
*   Rename Night\_Filters.py to EclipsingBinaries/Night\_Filters.py [`a91cd07`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a91cd07b92b7da1cf1809bc6918bceb01ffccc16)
*   Rename IRAF\_Reduction.py to EclipsingBinaries/IRAF\_Reduction.py [`8c215e2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8c215e2adb8fcba5e410ab1a09d69217419b79b6)

## [v2.1.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.8.6...v2.1.0) - 2023-01-25

### Merged

*   Fixed Undefined Import [`#48`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/48)
*   Update README.md [`#47`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/47)
*   Update for PyPi [`#46`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/46)
*   Update for PyPi [`#45`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/45)
*   Update and rename main.py to menu.py [`#44`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/44)

### Commits

*   Update CHANGELOG.md [`652f5d8`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/652f5d805032b6ddb0e45dddd594083457e5199a)

## [v0.8.6](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.8.5...v0.8.6) - 2023-01-20

### Merged

*   Output to a Latex File [`#41`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/41)

### Commits

*   Update CHANGELOG.md [`33f8e34`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/33f8e34c84b300212577145cf1c1342b0b8e4b49)
*   Update CHANGELOG.md [`815262e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/815262ec52a939dc4a9933b25342c27219a99c36)
*   Minor Updates [`7212bde`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7212bde20ba026f5247256f41049a6d00dde2975)
*   Update README.md [`e75705c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e75705c3a25993ebe8be1cbc2d3d3ba49be59b67)
*   Update CHANGELOG.md [`9948c5b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9948c5bfe5dea40fa099e41f33ce08b908caf302)

## [v0.8.5](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.8.4...v0.8.5) - 2023-01-19

### Merged

*   Update for the Name Change of Night Filters [`#40`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/40)
*   Combines AIJ and TESS Night Filters [`#39`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/39)

### Commits

*   Delete TESS\_Night\_Filters.py [`d7ab9c4`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d7ab9c438dbaf839d83653aaf08057af7e11466b)
*   Update Night\_Filters.py [`bbe4456`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/bbe4456e12fb8f5d091a13ff94f19d07ac4b3183)

## [v0.8.4](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.8.3...v0.8.4) - 2023-01-16

### Merged

*   Minor Fix To #36 [`#37`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/37)
*   Plot All O-C Data [`#36`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/36)

### Commits

*   Update CHANGELOG.md [`fe429a0`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/fe429a0f5b53f4353e4dd2328d6462f3ebea9d69)
*   Update CHANGELOG.md [`bc8ba0b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/bc8ba0bcf8e77ba4e003706ca9118f9e3b02d22b)
*   Update README.md [`9ded691`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9ded691b10a70ad3c69021cd9b59ed1eb26ac128)

## [v0.8.3](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.8.2...v0.8.3) - 2023-01-12

### Merged

*   Ability to Close the Program [`#35`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/35)
*   Added O-C Plotting [`#34`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/34)
*   Update CHANGELOG.md [`#33`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/33)

### Commits

*   Update bug\_report.md [`4350168`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/43501684b7aee2da95482091e90678d260b40860)
*   Update feature\_request.md [`5c65901`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5c65901da6c36a2e691ac31f4cc870424e01facb)
*   Update README.md [`1a6ad15`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/1a6ad15023c86099449015b764ff033ea1cc6d19)

## [v0.8.2](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.8.1...v0.8.2) - 2023-01-11

### Merged

*   Naming of Science Image Issues [`#32`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/32)

### Commits

*   Update README.md [`5f92c74`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5f92c74c9ef33f2e2b7efb32bc3b7d14b4629427)

## [v0.8.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.8.0...v0.8.1) - 2023-01-10

### Merged

*   Bias Image Plotting Update and Fixes [`#30`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/30)

### Commits

*   Removed Cosmic Ray [`edd4a65`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/edd4a6532f9dbb720fee64fd234b44ec23e23c41)
*   Update README.md [`8ea6665`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8ea666566f846ab902d2df65266ba838284a0fde)
*   Update CHANGELOG.md [`e73f9dd`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e73f9ddb721a7d39411df7040f2141a43e0f4d28)

## [v0.8.0](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.7.3...v0.8.0) - 2023-01-09

### Commits

*   Update CHANGELOG.md [`9a01a2f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9a01a2fe8a50f8e6b31eae8e3085d1db981af109)

## [v0.7.3](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.7.2...v0.7.3) - 2023-01-09

### Merged

*   Science Image Reduction [`#28`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/28)
*   Update README.md [`#27`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/27)
*   Numba Dependency [`#26`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/26)
*   Numba Dependency [`#25`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/25)
*   Create CHANGELOG.md [`#24`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/24)
*   Update CODE\_OF\_CONDUCT.md [`#23`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/23)
*   Update README.md [`#22`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/22)
*   Update main.py [`#21`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/21)
*   Update README.md [`#20`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/20)
*   Combine the two Branches [`#19`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/19)
*   Delete APASS\_catalog\_finder.py [`#14`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/14)
*   Delete Overlay\_Comparison.py [`#15`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/15)
*   Delete cousins\_R.py [`#16`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/16)
*   Delete APASS\_AIJ\_comparison\_selector.py [`#13`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/13)
*   Delete changelog directory [`#12`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/12)

### Commits

*   Add files via upload [`6b5c591`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/6b5c591d04043a8ab46c46efb29fd520a8212b75)
*   Update CHANGELOG.md [`b9b4d23`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b9b4d23729dcb4981ca7400f2b7f638679275410)
*   Update CHANGELOG.md [`b0514ed`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b0514ed2d39aa6c7a27574d37aa4fe995553de6f)
*   Update apass.py [`5818a7b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5818a7bfc765772e84ec31605e86d015f5c8c63c)

## [v0.7.2](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.7.1...v0.7.2) - 2022-12-26

### Merged

*   Simple Comment Updates [`#11`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/11)
*   Utilize Numba for Cousins R Calculations [`#10`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/10)
*   Utilize Numba [`#9`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/9)
*   Create package.json [`#8`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/8)

### Commits

*   Add Changelog [`70176ef`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/70176ef033a2eff06aa536f66bc8521d808eac6f)
*   Update CHANGELOG.md [`9056432`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9056432354e965ebb549a9c18bc81c726ae923c0)
*   Update CHANGELOG.md [`96a2d85`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/96a2d85861255f5718b628690358e67fd6aad35b)
*   Update CHANGELOG.md [`5780135`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/57801354b7dbc2596d51a584226425bf71e35e99)
*   Update README.md [`60f1ba2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/60f1ba2d4cf01ebb9d191fc1963cff18f665b4e5)
*   Update CHANGELOG.md [`5eab630`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5eab630eb714e93ef8ccf2ff9fa6fe2c5413ebb1)
*   Removed Unused Package [`adc3bb7`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/adc3bb7c0487e84e2d7d43bd33593a53a6e36a0e)

## [v0.7.1](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.7.0-alpha...v0.7.1) - 2022-12-23

### Merged

*   Adds BSUO Data Calculations [`#7`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/7)

### Commits

*   Update OC\_plot.py [`7e3f8c0`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7e3f8c0984c2c47b55cadd050800c7215bea8651)
*   Comment Out a Line [`9f48858`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9f48858208774afb4cfbd80f62550925a0299e19)

## [v0.7.0-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.6.4-alpha...v0.7.0-alpha) - 2022-12-22

### Commits

*   Create O-C\_plot.py [`973b78d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/973b78db5ade5c34dc991c2c74049f8ebf954127)
*   Calculate O-C Values [`3c74c23`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/3c74c23390acea31eee07228424dfb265be2a8bf)
*   Update README.md [`c4db064`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/c4db0647d4caa3173aa5b0c6c796c6d9d82a7be2)
*   Update README.md [`ae9f1d0`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ae9f1d07e31d405e05151d50525e0216ccb05c4b)
*   Update main.py [`d0f303e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d0f303ea4ef590ab09d0231095c4d069068deaef)
*   Update README.md [`9587187`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/958718754436d7873a54e1a409a5a83e67ca9993)
*   Update README.md [`35ee95d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/35ee95d3f89187e2bfb35a89207940c63ccded99)
*   Rename O-C\_plot.py to OC\_plot.py [`2ca9853`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2ca98538e2962bd0cb451084f6a38f0846099ea7)

## [v0.6.4-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.6.3-alpha...v0.6.4-alpha) - 2022-12-09

### Merged

*   Create CODE\_OF\_CONDUCT.md [`#3`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/3)

### Commits

*   Permanent Fix for Output Files [`925ad4f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/925ad4f9d9e0bb71bcce2554bf443927e9ad9b70)
*   Update issue templates [`4f75d30`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/4f75d3013d6dde0119c1bf6936d0b7ac7f0b1955)
*   Multiple Errors [`8d73ad9`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8d73ad9b10d018d9cdc5561b9b99a50758a49dbf)
*   Update issue templates [`43c51c4`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/43c51c44bcc8f04880f6ebe83648b100b30839c1)
*   Update README.md [`bf9a74d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/bf9a74d6c5e05a689decac449278b937da447c7b)
*   Update README.md [`4ac7857`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/4ac7857df8b217ebcb551c6ebe35ec1e35a7bb93)

## [v0.6.3-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.6.2-alpha...v0.6.3-alpha) - 2022-12-01

### Commits

*   Error Check Failed [`90ac01c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/90ac01cb25c5ae628645faecaba53284fcd02f7b)
*   Update AIJ\_Night\_Filters.py [`d944aa5`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d944aa5ffce5a7b99b213492d2528a92d743ffb3)
*   Update TESS\_Night\_Filters.py [`74fe32d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/74fe32d60820909260f61553427c76baf0af2946)
*   Update README.md [`0c2a116`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/0c2a116915435b46afc5c01c2adbfcedde97ec07)

## [v0.6.2-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.6.1-alpha...v0.6.2-alpha) - 2022-11-22

### Commits

*   Overlay APASS and AIJ comparison stars [`86f2418`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/86f24188c44feefacebe16b204ac09dbcb3e146e)
*   File to automatically setup dependencies [`578843f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/578843fa028d1120017985505f0a8eb6d8bb81a7)
*   Update tesscut.py [`dc96322`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/dc9632217903d86e2d75ac1ee876118edb06b803)
*   Update README.md [`ca89735`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ca897351a69c651283b2e2e556c0abd5114300fc)
*   Update README.md [`a147b7e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a147b7e7c06ef50a54f715f6834a35c56d580ee9)
*   Update README.md [`c82d37f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/c82d37f75b5a1ff1c98bd673e56633ad7b126384)
*   Minimum Requirements [`b3ebc1f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b3ebc1f22ad213da5acdc28a4412f05ce55d46bc)
*   30 arcmin change [`7d3f5cd`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7d3f5cd104ee58a60fabd109580bf19b4483ef3e)
*   Required Python Packages [`c651618`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/c651618bcefc82d75fd1429438c799d6a9c853a8)
*   Comparison Overlay [`ff65a2b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ff65a2bb8325f4311983bae77ded770dcd5ad0da)
*   Update README.md [`2c525ec`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2c525ecebc1b2779695a18c2323b9ef44f984edd)
*   Update README.md [`875496f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/875496fb2a17f657d695ceaa84372f09aeabcef5)
*   Update README.md [`ef501b4`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ef501b471eaa30c31a6b10cdfd466afce187f4f4)
*   Update tesscut.py [`667a5d6`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/667a5d6da0c7ea771ee866219f4bb4ba32d34ba5)
*   Update setup.py [`b535e99`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b535e995ddbc67eb0d39f617c2db6278f99bd77d)
*   Update README.md [`2d9a5e9`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2d9a5e91d876ef99abc59b51ba2b1f87a61487f6)
*   Update README.md [`49c0477`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/49c047777c699aeab4b81931cb73002673950439)
*   Update README.md [`4d3e39d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/4d3e39db00d6a9d001fa0c35691463b1fdb5352b)
*   Update README.md [`9a03d8e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9a03d8e86bbfcb142b8453b1402095b5854da344)
*   Update README.md [`bb7e11e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/bb7e11e98ab44a248ac66b841d892031fbde30d4)
*   Update README.md [`12337c5`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/12337c58b948808e6712313285d9533cea8e2892)
*   Update setup.py [`87f3d0c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/87f3d0ce838a9caf22a94c505c788d4f6ab2024e)

## [v0.6.1-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.6.0-alpha...v0.6.1-alpha) - 2022-11-17

### Commits

*   Delete convenience\_functions.py [`2cdff38`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2cdff381268ab2b103ed32727e3e83c4fdfed6b5)
*   Science Images [`7fe3c10`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7fe3c1070f69bc191c325b803e468d28f8618edf)
*   Massive Updates [`6cb755e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/6cb755eb24ac063afc9664f905974386d0ff3a62)
*   Original File Name [`68f4f34`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/68f4f3492f485c80bd1760f3564b1154bffff044)
*   Converting BJD to HJD [`1f61af7`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/1f61af7a7c7efb955584fe4b97f0632c1548fa82)
*   Create codeql.yml [`f61acd6`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f61acd6d0ad04b88eb3f0c80a271f7926533f7eb)
*   Minor Changes [`3840c0a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/3840c0ae8109f163536cc2e775752deb05d60311)
*   Update tess\_data\_search.py [`5e60984`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5e609847fa16c51a4f34961ea5f022b1f649ec8f)
*   Update README.md [`d8a3cc4`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d8a3cc403352e2f322aa99d28929b835832fee9a)
*   Download Pixel Size [`266e23a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/266e23af85f33b9446dd48a0416837be49de3aab)

## [v0.6.0-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.5.3-alpha...v0.6.0-alpha) - 2022-11-10

### Commits

*   IRAF Reduction Process [`b3c1cc1`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b3c1cc1b2a00ec9a8f3a6701069ff450672bd4da)
*   Column Input File Number [`98710c9`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/98710c94497b5acd3ea26a8c6287d435b0f33640)
*   Spacing Fix [`b0ae2fb`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b0ae2fbebbf1694feef1c2c5b135705978a6392e)
*   Includes IRAF Reduction [`1f12eec`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/1f12eec319b66940cdc0571412baf32408f128f9)
*   Update README.md [`3a63b81`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/3a63b81b923895673a9b84debc5624efec64a6fb)
*   Leaving the Porgram [`f8bf17b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f8bf17b6122c701e611e215367a54a49e014a42a)

## [v0.5.3-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.5.2-alpha...v0.5.3-alpha) - 2022-11-04

### Commits

*   Comments Update [`e8af20c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e8af20c5bcd525d175993f7c1a6cca20e7e5734b)
*   Comments Update [`ca7bdad`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ca7bdadd8bfc13d4bae4bcd9b888060f099d49fc)

## [v0.5.2-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.5.1-alpha...v0.5.2-alpha) - 2022-11-04

### Commits

*   Arranging Updates [`baa7b2a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/baa7b2a257fe10c4b7ac62491aec256ce57952e0)
*   Update APASS\_catalog\_finder.py [`1b596d8`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/1b596d8bdec388829cf683793a78e6aef849c3a9)
*   Update color\_light\_curve.py [`eb7b4a5`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/eb7b4a58eb1925890b3432327a7c4f86e1fd7fe7)

## [v0.5.1-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.5.0-alpha...v0.5.1-alpha) - 2022-11-03

### Commits

*   Closing the Porgram [`81f3c82`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/81f3c827d5520c45128c0bc827543f4c467347ae)

## [v0.5.0-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.4.3-alpha...v0.5.0-alpha) - 2022-11-03

### Merged

*   Changes to the output Files [`#1`](https://github.com/kjkoeller/Binary_Star_Research_Package/pull/1)

### Commits

*   Update color\_light\_curve.py [`ecd4416`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ecd4416d679750a8981f0a28b33be81ecb152294)
*   Closing the Program [`9ef4bd0`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9ef4bd0e15e7e4f4ccb4dc215d0350c6b678d9da)
*   Closing the Program [`729f088`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/729f0882bdb19b5f23f72b28abd1d4f28bd83478)
*   Misspelled Variable [`96ea095`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/96ea09544c353c453dee2afa874bf3e30c9d4e2d)
*   Going Back from AIJ Selection [`08d1c67`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/08d1c67e939564ed4b01ccd4d1e76ee1739f090a)
*   Redundant Options [`cff5f25`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/cff5f255d912d8921ca53857776d2e40502c513f)
*   Close Program [`5bd38c0`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5bd38c00fe2889745915e8fc3a9b6936acf31088)
*   Closing the Program [`a0e4ddd`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a0e4ddd7bc9ee898a2c82aaa7713a1a410d0820e)
*   Update AIJ\_Night\_Filters.py [`a115ec8`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a115ec8f92a46ea892abb726becaf543ee68c927)
*   Update AIJ\_Night\_Filters.py [`b92c9a8`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b92c9a805c4e8856e0e392b22272fcbc73c86e7f)
*   Update AIJ\_Night\_Filters.py [`f7e5010`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f7e5010905d4a7f38ea27928a9b239a38df268fd)

## [v0.4.3-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.4.2-alpha...v0.4.3-alpha) - 2022-11-02

### Commits

*   Duplicate Code [`17f7e08`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/17f7e083f98425f88fb110b4887a7f460356e922)
*   Code efficiencies [`2bb91eb`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2bb91eb65150ed591b888c0753b2104de37ffec2)
*   Allows for continuous use [`2a16968`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2a1696872ac36135383b99a1d409a87487c74ef3)
*   Update color\_light\_curve.py [`41d23c0`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/41d23c068f08842a2fc16e95f5cd946cb188ddb7)
*   Update README.md [`a173b7b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a173b7bf95b32a5e43f9aac36e33387f94d72228)

## [v0.4.2-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.4.1-alpha...v0.4.2-alpha) - 2022-11-01

### Commits

*   Update vseq\_updated.py [`a32707f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a32707f1d0ac9c1f4b4c84dec850a2db227c2819)
*   Update color\_light\_curve.py [`b9c5a06`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b9c5a0698ece208b6c71513df8d621bcce8495d7)
*   Import Edit [`08247c3`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/08247c32553359daf74ff4bfed808e72207d0c64)
*   Update color\_light\_curve.py [`4272f52`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/4272f52c619d85aa9e1eef1b1af7588cf90825c7)
*   Update vseq\_updated.py [`fae261a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/fae261a77330d568f877c2f4a4ac0dc1f542496a)
*   Update color\_light\_curve.py [`bff3f21`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/bff3f215b8fc28cf3a23f0e64b0b3476ee7e6746)

## [v0.4.1-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.4.0-alpha...v0.4.1-alpha) - 2022-11-01

### Commits

*   Remove Testing Imports [`b9f144c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b9f144c09aa625334c6860abdfc12586ec672693)

## [v0.4.0-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.3.1-alpha...v0.4.0-alpha) - 2022-10-26

### Commits

*   Update vseq\_updated.py [`7e4cbf9`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7e4cbf9c1508a4ce03664d7ccc0c9e7722805096)
*   Update vseq\_updated.py [`98234a1`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/98234a1e563bfff022be5466ceee58d085bb8550)
*   Add Color Light Curve [`e48ae20`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e48ae20d2851ee771cf3217472dbc9961c2a2c3f)
*   Updated comments [`9070dfd`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9070dfd9bbc704364e89044615bbec1e63326055)
*   Update vseq\_updated.py [`5743ec5`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/5743ec51e1db0147760a206ea99f488c8e2902ac)
*   Comments and Enumerate [`2f024dc`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/2f024dc9d7929ed715f8b93a2a78d17132027da6)
*   Equality Fixes [`f0f2edf`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f0f2edfd8f6181becf9218e51b9d92143581230b)
*   Error Propogation [`20771ad`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/20771ad2d19bf6b603f59dda5a5f8be7684a01c4)
*   Update tesscut.py [`d27f28c`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/d27f28cfa78117507a1bea9385212d12adc41d47)
*   Update tesscut.py [`dc39bd2`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/dc39bd217d77b10bebf1a412beb60238b4274ea6)
*   Update main.py [`9c00f63`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9c00f63142854dbc564607be5a201180896d85ea)
*   Update OConnell.py [`dc2468d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/dc2468de3739485abc0616506c06c3ddc99f78d1)
*   Update README.md [`7625fa7`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7625fa70c3709893cd2558b3c5432baa04766121)
*   Input Type [`9824d5a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9824d5a07fe539e1dace23e03b0d6930b7337d24)
*   Removed double import [`b4f4330`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b4f433075155b1a9aa552b830dd2a4c85697879b)
*   Update vseq\_updated.py [`4c26701`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/4c267017fc746f2e6e394634e38accdaa6cff2eb)
*   Rename vs\_color\_light\_curve.py to color\_light\_curve.py [`ed9b89e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ed9b89e65f81260861573c336a404395caeeb81a)

## [v0.3.1-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.2.1-alpha...v0.3.1-alpha) - 2022-09-09

### Commits

*   Adds the TESSCut File [`c3b88cf`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/c3b88cf9d0649aeef00db336d7b93d59512827be)
*   Added the TESSCut Ability [`1dc61f9`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/1dc61f9a9dda97c0d0deefe94a7aab5c49ca61c0)
*   Adds Prompt for TESS [`04f984a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/04f984afaea73548089dd1f2d231e144a2c70cc1)
*   Update README.md [`542da02`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/542da023d071245b26a7a6696df5f6ce062cbecd)
*   Update README.md [`1208c1f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/1208c1fec42d9f621d753d4202a01d25e1311b61)
*   Update README.md [`baed528`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/baed528058eeac1fe63dd6809c9a9f7be97fdcff)

## [v0.2.1-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.2.0-alpha...v0.2.1-alpha) - 2022-08-30

### Commits

*   Input Changes [`72a98ad`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/72a98ad427ddf7188aa41053197f173e9d17df00)

## [v0.2.0-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.1.1-alpha...v0.2.0-alpha) - 2022-08-30

### Commits

*   Added the O'Connel Code [`4f59aff`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/4f59aff7901c3da473302d8291218f52cb160499)
*   Create python-app.yml [`f5386a5`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f5386a50a2eb363492a0f2377b9e25364761ee48)
*   Update vseq\_updated.py [`b7d3117`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b7d31176acc9b59fbb6b11d83fc9810940a83868)
*   Added O'Connel Effect Option [`f0011dc`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/f0011dcda9de71f411ddadc70074b2c4de706a94)
*   Update OConnell.py [`e222fae`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e222fae2bd9a2e4e6150151adf8b035f684ecc23)
*   Update OConnell.py [`aa9bd00`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/aa9bd00db3ec6a89577f399c6c8659543f2c676c)
*   Update cousins\_R.py [`8e05b69`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/8e05b69b2093d96b80677343cbf74a1abbfa12b7)
*   Update cousins\_R.py [`6ef701e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/6ef701e974d76413c4d873ae523ffe2b7b46f540)
*   Update python-app.yml [`b069f93`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/b069f932f003299e3967d13b16fb4c8e9939ce7d)
*   Update README.md [`7948e9f`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/7948e9fba2c99e45336b68512c9d85ef6f6e39d6)
*   Update cousins\_R.py [`ff759df`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ff759dffaa2a2c445cd95a1db875f2aee83ef6dd)
*   Update README.md [`45d2afb`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/45d2afbd3062d67988990d1a145e3e558829d558)

## [v0.1.1-alpha](https://github.com/kjkoeller/Binary_Star_Research_Package/compare/v0.1.0-alpha...v0.1.1-alpha) - 2022-08-29

### Commits

*   Removed a Commented Section [`10ac3d6`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/10ac3d625db1054260f1e3a2c4be844662c1e80d)
*   Try Except Change [`906262d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/906262df547b7f471e2e6d75f3223e4f5b736d8a)
*   Removed Unused Variable [`a25c151`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a25c1510d2412450849cf68ab6e9f1435d50e06b)
*   Update APASS\_AIJ\_comparison\_selector.py [`9a92254`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/9a92254ab61ff88175f8e3c19d7c03d8ce73e1af)
*   Added Codacy Badge [`65bfd63`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/65bfd638d678012a5c45fc874b49d9eba184c1a5)

## v0.1.0-alpha - 2022-08-29

### Commits

*   Add files via upload [`289aa00`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/289aa004c5af091e92a90792b75ce01db9f1d66b)
*   Delete .github/workflows directory [`a85b796`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/a85b796bdcf5c830443433b8dee216a08f4dd95d)
*   Create python-package.yml [`69fb87d`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/69fb87d243d5b7630b83b87f95459400f7043ac5)
*   Create python-publish.yml [`845ef2b`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/845ef2b01be269524f6a43157a966ce8a8e72fda)
*   Create python-package-conda.yml [`abc903e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/abc903e4dcb9d00d98b4e6e14cf368f8f08a671c)
*   Update README.md [`cdd7277`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/cdd727720015cccf3e3a465fd06c74d2b82fef36)
*   Initial commit [`03bf34e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/03bf34e47a390e28ee484b3a478c0c62156b9c94)
*   Update python-package-conda.yml [`035a07e`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/035a07ec8131ad99ec4a9390851eae0a6badfef3)
*   Update python-package-conda.yml [`e921470`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/e9214700517f57de539f4bd22826dd4484c8faac)
*   Update python-package.yml [`ac9539a`](https://github.com/kjkoeller/Binary_Star_Research_Package/commit/ac9539a02b5412affdc9250c8d243bb48635e57a)
